@@ -1,5 +1,6 @@
-from aiida.orm import StructureData, KpointsData
+from aiida.orm import StructureData, KpointsData, Dict
 from copy import deepcopy
+from aiida.orm import load_node
 
 def qePwOriginalSubmit(results, codename, structure, add_parameters, del_parameters, kpoints, pseudo_family, cluster_options, metadata):
 
